@@ -1,6 +1,6 @@
 from grid.cli.cli.grid_artifacts import artifacts
 from grid.cli.cli.grid_clusters import clusters
-from grid.cli.cli.grid_credentials import credentials
+from grid.cli.cli.grid_credentials import credential
 from grid.cli.cli.grid_datastore import datastore
 from grid.cli.cli.grid_delete import delete
 from grid.cli.cli.grid_edit import edit
@@ -24,7 +24,7 @@ __all__ = [
     'login',
     'run',
     'stop',
-    'credentials',
+    'credential',
     'history',
     'logs',
     'session',
