@@ -36,6 +36,8 @@ def _check_is_experiment(ctx, _param, value):
 )
 def status(run: Optional[str] = None, is_global: Optional[bool] = False) -> None:
     """Checks the status of Runs, Experiments, and Sessions."""
+
+    click.echo(f"Loading status in {env.CONTEXT}")
     # Initializing variables
     spinner_load_type = "Runs"
     history_runs = []
@@ -47,7 +49,7 @@ def status(run: Optional[str] = None, is_global: Optional[bool] = False) -> None
     # Fetching runs/experiments and printing them onto the terminal
     try:
         spinner.start()
-        runs = list_runs(is_global=is_global)
+        runs = list_runs(is_global=is_global, query=run)
         if not run:
             table = render_runs(runs, is_global=is_global)
             history_runs = len(runs) - len(table.rows)
@@ -168,25 +170,17 @@ def render_runs(runs: List['Run'], is_global: bool) -> Table:
 
 
 def render_experiments(experiments: List['Experiment']) -> Table:
-    base_columns = [
+    table = create_table([
         'Experiment',
-        'Command',
         'Status',
         'Queued Duration',
         'Run Duration',
-    ]
-    if not experiments:
-        return create_table(base_columns)
-    command = experiments[0].command
-    hparams = [tok.replace('--', '') for tok in command if '--' in tok]
-
-    table_columns = base_columns + hparams
-    table = create_table(table_columns)
+        'Command',
+    ])
 
     for experiment in experiments:
         # Split hparam vals
-        command = experiment.command
-        base_command, *hparam_vals = get_param_values(" ".join(command))
+        command = " ".join(experiment.command)
 
         duration_str = get_experiment_duration_string(
             created_at=experiment.created_at,
@@ -197,7 +191,5 @@ def render_experiments(experiments: List['Experiment']) -> Table:
             created_at=experiment.created_at,
             started_running_at=experiment.start_timestamp,
         )
-        table.add_row(
-            experiment.name, base_command, experiment.status.value, queued_duration_str, duration_str, *hparam_vals
-        )
+        table.add_row(experiment.name, experiment.status.value, queued_duration_str, duration_str, command)
     return table
