@@ -124,6 +124,8 @@ def create_openapi_object(json_obj: Dict, target: Any):
 
         if is_openapi(sub_target):  # it's an openapi object
             target_attribs[key] = create_openapi_object(value, sub_target)
+        elif isinstance(sub_target, list):
+            target_attribs[key] = [create_openapi_object(v, sub_target[0]) for v in value]
         else:
             target_attribs[key] = value
 
