@@ -18,7 +18,7 @@ from gql.transport.exceptions import TransportProtocolError, TransportQueryError
 from gql.transport.requests import RequestsHTTPTransport
 from gql.transport.websockets import WebsocketsTransport
 
-from grid.cli.commands import CredentialsMixin, DependencyMixin, WorkflowChecksMixin
+from grid.cli.commands import DependencyMixin, WorkflowChecksMixin
 from grid.cli.observables import Experiment, InteractiveNode, Run
 from grid.cli.types import ObservableType
 from grid.metadata import __version__
@@ -62,7 +62,7 @@ def credentials_from_env(credential_path: Optional[str] = None) -> StaticCredent
     )
 
 
-class Grid(CredentialsMixin, WorkflowChecksMixin, DependencyMixin):
+class Grid(WorkflowChecksMixin, DependencyMixin):
     """
     Interface to the Grid API.
 
