@@ -37,6 +37,7 @@ def create_datastore(
     fsx_enabled: bool = False,
     fsx_capacity_gib: int = 1200,
     fsx_throughput_mbs_tib: int = 125,
+    fsx_preloading: bool = False
 ) -> V1CreateDatastoreResponse:
     """Create a new datastore.
 
@@ -60,6 +61,8 @@ def create_datastore(
         The capacity of the FSx file system backing a datastore in GiB, only to be used with fsx_source_type=True
     fsx_throughput_mbs_tib
         The throughput per unit of storage for the datastore in MB/s/TiB, only to be used with fsx_source_type=True
+    fsx_preloading
+        Whether to preload the data on datastore creation, only to be used with fsx_source_type=True
     """
     if Path(source).exists():
         source_type = V1DatastoreSourceType.EXPANDED_FILES
@@ -100,7 +103,9 @@ def create_datastore(
             raise ValueError(errors.datastore_invalid_fsx_capacity(fsx_capacity_gib))
 
         fsx_spec = V1DatastoreFSxSpec(
-            storage_capacity_gib=fsx_capacity_gib, storage_throughput_mb_s_tib=fsx_throughput_mbs_tib
+            storage_capacity_gib=fsx_capacity_gib,
+            storage_throughput_mb_s_tib=fsx_throughput_mbs_tib,
+            preload_data_on_create=fsx_preloading,
         )
 
     resp = c.datastore_service_create_datastore(
