@@ -99,7 +99,18 @@ class S3Uploader:
         disconnect_retries = retries
         while disconnect_retries > 0:
             try:
-                retries = Retry(total=10)
+                # Retries logic is borrowed from datastore_uploads.py
+                retries = Retry(
+                    total=8,
+                    # status_forcelist retry codes
+                    # ----------------------------
+                    # 104: connection reset by peer can occur when 307 redirect requests aren't received quickly enough.
+                    # 429: too many requests (just need to slow down... exponential backoff handles this)
+                    # 500, 502, 503, 504: assorted errors AWS uses to say "yeah... we screwed up"
+                    status_forcelist=[104, 429, 500, 502, 503, 504],
+                    method_whitelist=["HEAD", "GET", "PUT", "POST"],
+                    backoff_factor=2,
+                )
                 with requests.Session() as s:
                     s.mount('http://', HTTPAdapter(max_retries=retries))
                     s.mount('https://', HTTPAdapter(max_retries=retries))
